/*
 * KIELER - Kiel Integrated Environment for Layout Eclipse RichClient
 *
 * http://www.informatik.uni-kiel.de/rtsys/kieler/
 * 
 * Copyright 2012 by
 * + Christian-Albrechts-University of Kiel
 *   + Department of Computer Science
 *     + Real-Time and Embedded Systems Group
 * 
 * This code is provided under the terms of the Eclipse Public License (EPL).
 * See the file epl-v10.html for the license text.
 */
package de.cau.cs.kieler.kiml.formats.gml;

import org.eclipse.core.runtime.Plugin;
import org.osgi.framework.BundleContext;

import com.google.inject.Guice;
import com.google.inject.Injector;
import com.google.inject.Module;

import java.util.HashMap;
import java.util.Map;

/**
 * The plugin activator class. This class was originally generated by Xtext.
 * 
 * @author msp
 * @kieler.design proposed by msp
 * @kieler.rating proposed yellow by msp
 */
public class GmlActivator extends Plugin {

    /** the GML language identifier. */
    public static final String GML = "de.cau.cs.kieler.kiml.formats.gml.GML";

    /** the injectors cache. */
    private Map<String, Injector> injectors = new HashMap<String, Injector>();

    /** the shared instance. */
    private static GmlActivator instance;

    /**
     * Returns an injector for the GML language.
     * 
     * @param languageName the language name
     * @return an injector
     */
    public Injector getInjector(final String languageName) {
        Injector injector = injectors.get(languageName);
        if (injector == null) {
            Module runtimeModule = getRuntimeModule(languageName);
            injector = Guice.createInjector(runtimeModule);
            injectors.put(languageName, injector);
        }
        return injector;
    }

    @Override
    public void start(final BundleContext context) throws Exception {
        super.start(context);
        instance = this;
    }

    @Override
    public void stop(final BundleContext context) throws Exception {
        injectors.clear();
        instance = null;
        super.stop(context);
    }

    /**
     * Returns the shared instance.
     * 
     * @return the shared instance
     */
    public static GmlActivator getInstance() {
        return instance;
    }

    /**
     * Returns the runtime module.
     * 
     * @param grammar the grammar name
     * @return the runtime module
     */
    protected Module getRuntimeModule(final String grammar) {
        if (GML.equals(grammar)) {
            return new GMLRuntimeModule();
        }
        throw new IllegalArgumentException(grammar);
    }

}
