package de.cau.cs.kieler.klighd.examples.ecore;

import com.google.common.base.Objects;
import com.google.common.collect.Iterables;
import de.cau.cs.kieler.core.kivi.AbstractCombination;
import de.cau.cs.kieler.core.kivi.ITriggerState;
import de.cau.cs.kieler.core.kivi.triggers.PartTrigger;
import de.cau.cs.kieler.core.kivi.triggers.SelectionTrigger;
import de.cau.cs.kieler.klighd.KlighdTreeSelection;
import de.cau.cs.kieler.klighd.examples.ecore.EModelElementCollection;
import de.cau.cs.kieler.klighd.examples.ecore.EcoreModelAccess;
import de.cau.cs.kieler.klighd.kivi.effects.KlighdUpdateDiagramEffect;
import de.cau.cs.kieler.klighd.krendering.SimpleUpdateStrategy;
import de.cau.cs.kieler.klighd.util.KlighdProperties;
import de.cau.cs.kieler.klighd.util.KlighdSynthesisProperties;
import java.lang.reflect.Method;
import java.net.URI;
import java.util.List;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.IPath;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EModelElement;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.part.FileEditorInput;
import org.eclipse.xtext.xbase.lib.CollectionLiterals;
import org.eclipse.xtext.xbase.lib.Exceptions;
import org.eclipse.xtext.xbase.lib.Functions.Function1;
import org.eclipse.xtext.xbase.lib.IterableExtensions;
import org.eclipse.xtext.xbase.lib.ObjectExtensions;
import org.eclipse.xtext.xbase.lib.Procedures.Procedure1;

/**
 * Combination that triggers the synthesis of Ecore diagrams.
 * 
 * @author chsch
 */
@SuppressWarnings("all")
public class EcoreDiagramSynthesisCombination extends AbstractCombination {
  public EcoreDiagramSynthesisCombination() {
    try {
      Class<?> _forName = Class.forName("org.eclipse.emf.ecoretools.diagram.navigator.EcoreDomainNavigatorItem");
      this.navItemClass = _forName;
      Method _method = this.navItemClass.getMethod("getEObject");
      this.eObjectGetter = _method;
    } catch (final Throwable _t) {
      if (_t instanceof Throwable) {
        final Throwable t = (Throwable)_t;
      } else {
        throw Exceptions.sneakyThrow(_t);
      }
    }
  }
  
  private Class<?> navItemClass = null;
  
  private Method eObjectGetter = null;
  
  /**
   * The 'execute()' method, see doc of {@link AbstractCombination}.
   */
  public void execute(final PartTrigger.PartState es, final SelectionTrigger.SelectionState selectionState) {
    ISelection _selection = selectionState.getSelection();
    if ((_selection instanceof KlighdTreeSelection)) {
      return;
    }
    boolean _or = false;
    ITriggerState _latestState = this.latestState();
    boolean _equals = Objects.equal(_latestState, es);
    if (_equals) {
      _or = true;
    } else {
      PartTrigger.EventType _eventType = es.getEventType();
      boolean _equals_1 = Objects.equal(_eventType, PartTrigger.EventType.VIEW_DEACTIVATED);
      _or = _equals_1;
    }
    if (_or) {
      return;
    }
    final List<?> selection = selectionState.getSelectionElements();
    boolean _isNullOrEmpty = IterableExtensions.isNullOrEmpty(selection);
    if (_isNullOrEmpty) {
      return;
    }
    IPath editorInputPath = null;
    String viewId = null;
    String viewName = null;
    EModelElementCollection modelElements = null;
    IWorkbenchPart sourceWorkbenchPart = null;
    boolean _and = false;
    IEditorPart _editorPart = es.getEditorPart();
    boolean _notEquals = (!Objects.equal(_editorPart, null));
    if (!_notEquals) {
      _and = false;
    } else {
      IEditorPart _editorPart_1 = es.getEditorPart();
      IEditorInput _editorInput = _editorPart_1.getEditorInput();
      boolean _isInstance = FileEditorInput.class.isInstance(_editorInput);
      _and = _isInstance;
    }
    if (_and) {
      IEditorPart _editorPart_2 = es.getEditorPart();
      IEditorInput _editorInput_1 = _editorPart_2.getEditorInput();
      final FileEditorInput fileEditorInput = FileEditorInput.class.cast(_editorInput_1);
      boolean _and_1 = false;
      IFile _file = fileEditorInput.getFile();
      boolean _notEquals_1 = (!Objects.equal(_file, null));
      if (!_notEquals_1) {
        _and_1 = false;
      } else {
        IFile _file_1 = fileEditorInput.getFile();
        URI _locationURI = _file_1.getLocationURI();
        boolean _notEquals_2 = (!Objects.equal(_locationURI, null));
        _and_1 = _notEquals_2;
      }
      if (_and_1) {
        IPath _path = fileEditorInput.getPath();
        editorInputPath = _path;
      }
    }
    boolean _notEquals_3 = (!Objects.equal(editorInputPath, null));
    if (_notEquals_3) {
      String _portableString = editorInputPath.toPortableString();
      String _replace = _portableString.replace(":", "");
      viewId = ((String) _replace);
      String _lastSegment = editorInputPath.lastSegment();
      viewName = _lastSegment;
      List<?> _selectionElements = selectionState.getSelectionElements();
      Iterable<EModelElement> _filter = Iterables.<EModelElement>filter(_selectionElements, EModelElement.class);
      List<EModelElement> _list = IterableExtensions.<EModelElement>toList(_filter);
      EModelElementCollection _of = EModelElementCollection.of(_list);
      modelElements = _of;
    }
    boolean _isNullOrEmpty_1 = IterableExtensions.isNullOrEmpty(modelElements);
    if (_isNullOrEmpty_1) {
      List<EModelElement> elements = null;
      final Function1<Object, Boolean> _function = new Function1<Object, Boolean>() {
        public Boolean apply(final Object it) {
          boolean _or = false;
          boolean _isInstance = EPackage.class.isInstance(it);
          if (_isInstance) {
            _or = true;
          } else {
            boolean _isInstance_1 = EClass.class.isInstance(it);
            _or = _isInstance_1;
          }
          return Boolean.valueOf(_or);
        }
      };
      boolean _forall = IterableExtensions.forall(selection, _function);
      if (_forall) {
        Iterable<EModelElement> _filter_1 = Iterables.<EModelElement>filter(selection, EModelElement.class);
        List<EModelElement> _list_1 = IterableExtensions.<EModelElement>toList(_filter_1);
        elements = _list_1;
      } else {
        boolean _and_2 = false;
        boolean _notEquals_4 = (!Objects.equal(this.navItemClass, null));
        if (!_notEquals_4) {
          _and_2 = false;
        } else {
          boolean _notEquals_5 = (!Objects.equal(this.eObjectGetter, null));
          _and_2 = _notEquals_5;
        }
        if (_and_2) {
          final Function1<Object, Boolean> _function_1 = new Function1<Object, Boolean>() {
            public Boolean apply(final Object it) {
              return Boolean.valueOf(EcoreDiagramSynthesisCombination.this.navItemClass.isInstance(it));
            }
          };
          boolean _forall_1 = IterableExtensions.forall(selection, _function_1);
          if (_forall_1) {
            List<?> _selectionElements_1 = selectionState.getSelectionElements();
            Iterable<?> _filter_2 = Iterables.filter(_selectionElements_1, this.navItemClass);
            final Function1<Object, Object> _function_2 = new Function1<Object, Object>() {
              public Object apply(final Object it) {
                try {
                  return EcoreDiagramSynthesisCombination.this.eObjectGetter.invoke(it);
                } catch (Throwable _e) {
                  throw Exceptions.sneakyThrow(_e);
                }
              }
            };
            Iterable<Object> _map = IterableExtensions.map(_filter_2, _function_2);
            Iterable<EModelElement> _filter_3 = Iterables.<EModelElement>filter(_map, EModelElement.class);
            List<EModelElement> _list_2 = IterableExtensions.<EModelElement>toList(_filter_3);
            elements = _list_2;
          }
        }
      }
      viewId = "de.cau.cs.kieler.klighd.examples.ecore.explorer";
      viewName = "KLighD Class Diagram";
      boolean _notEquals_6 = (!Objects.equal(elements, null));
      if (_notEquals_6) {
        this.selectedModelElements.retainAll(elements);
        elements.removeAll(this.selectedModelElements);
        Iterables.<EModelElement>addAll(this.selectedModelElements, elements);
        EModelElementCollection _of_1 = EModelElementCollection.of(this.selectedModelElements);
        modelElements = _of_1;
      }
    }
    boolean _and_3 = false;
    boolean _notEquals_7 = (!Objects.equal(viewId, null));
    if (!_notEquals_7) {
      _and_3 = false;
    } else {
      boolean _isNullOrEmpty_2 = IterableExtensions.isNullOrEmpty(modelElements);
      boolean _not = (!_isNullOrEmpty_2);
      _and_3 = _not;
    }
    if (_and_3) {
      KlighdUpdateDiagramEffect _klighdUpdateDiagramEffect = new KlighdUpdateDiagramEffect(viewId, viewName, modelElements, sourceWorkbenchPart);
      final Procedure1<KlighdUpdateDiagramEffect> _function_3 = new Procedure1<KlighdUpdateDiagramEffect>() {
        public void apply(final KlighdUpdateDiagramEffect it) {
          it.<String>setProperty(KlighdSynthesisProperties.REQUESTED_UPDATE_STRATEGY, SimpleUpdateStrategy.ID);
          EcoreModelAccess _ecoreModelAccess = new EcoreModelAccess(EcoreDiagramSynthesisCombination.this.selectedModelElements);
          it.<EcoreModelAccess>setProperty(KlighdProperties.MODEL_ACCESS, _ecoreModelAccess);
        }
      };
      KlighdUpdateDiagramEffect _doubleArrow = ObjectExtensions.<KlighdUpdateDiagramEffect>operator_doubleArrow(_klighdUpdateDiagramEffect, _function_3);
      this.schedule(_doubleArrow);
    }
  }
  
  private List<EModelElement> selectedModelElements = CollectionLiterals.<EModelElement>newLinkedList();
}
